%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% generate_simulations:
%
% Generate a batch of problems to be used as a benchmark to compare
% methods. This relies on an external file ('seed_file.mat') to start the
% random number generator in a reproducible way.
%
% Created by: Ricardo Silva, London, 20/03/2012
% University College London
% Current version: 20/03/2012

load('seed_file.mat')
rng(s)

num_simulations = 20;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simulation parameters

num_x       = 4; % Number of latent variables
num_ind     = 4; % Number of indicators per latent variable
num_y       = num_x * num_ind; % Total number of indicators

prob_edge   = 0.2; % Probability of a bi-directed edge 

signal_range = [0.25 0.6]; % How much of the variance is due to the latent factor
marg_range   = [0.1 0.9];  % Marginal probabilities range
cop_range    = [10 15];    % Range for copula parameters

N = 10000; % Sample size

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate and save models


for i = 1:num_simulations
  fprintf('** GENERATING FILE BATCH #%d\n', i);
  filename = strcat('synth', int2str(i), '.mat');  
  [Y Y_parents bidir_graph L_true copula_theta copula_true expo_y true_cov_X] = ...
    synthetic_mcdn(num_x, num_ind, num_y, prob_edge, signal_range, ...
                   marg_range, cop_range, N);
  fprintf('* Number of edges = %d\n', sum(sum(bidir_graph)) / 2)               
  save(filename, 'Y', 'Y_parents', 'bidir_graph', 'L_true', ...
       'copula_theta', 'copula_true', 'expo_y', 'true_cov_X');         
end
disp('DONE')
    