%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get_expo_y:
%
% Get the marginal exponents of copula factors within a component of the 
% composite likelihood score function.
%
% Input:
%
% - Y_scope: variables in this region
% - G: the bi-directed graph
%   
% Output:
% 
% - W: the corresponding matrix of coefficients
%
% Created by: Ricardo Silva, London, 11/03/2012
% University College London
% Current version: 11/03/2012

function W = get_expo_y(Y_scope, G)

num_y_scope = length(Y_scope);
W = G(Y_scope, Y_scope) * 1; % Transforms "logical" into "double"

% Number of factors each variable belongs to
num_factors = max(sum(G(Y_scope, :), 2), 1); 

% Number of bivariate factors each variable belongs to in the scope
num_sp_scope = sum(W, 2);

% Adjust marginal exponents by subtracting only bivariate factors in scope
for y = 1:num_y_scope
  W(y, y) = num_factors(y) - num_sp_scope(y);
end

% Renormalize
W = W ./ repmat(num_factors, 1, num_y_scope);
