%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% init_embedding:
%
% Find initial score estimates for each latent variable and each univariate
% configuration.
%
% Input:
%
% - L: loadings
%   
% Output:
% 
% - X_start: a matrix indicating which value of the latent parent is best
%            for each marginal configuration of the observed variables
%
% Created by: Ricardo Silva, London, 27/03/2012
% University College London
% Current version: 27/03/2012

function X_start = init_embedding(L)

num_y = size(L, 1);
X_start = zeros(num_y, 2);

options_optim = optimset('GradObj', 'off', 'LargeScale', 'off', ...
                         'Display', 'off', 'DerivativeCheck', 'off', ...
                         'TolFun', 1.e-3);

for y = 1:num_y
  x_0 = 0;  
  X_start(y, 1) = fminunc(@(x)score_uni0(x), x_0, options_optim);
  X_start(y, 2) = fminunc(@(x)score_uni1(x), x_0, options_optim);
end

  function s = score_uni0(x)
    p = normcdf(0, L(y, 1) * x + L(y, 2), 1);
    if p == 0, p = eps; end
    s = -log(p) + 0.5 * x.^2;
  end

  function s = score_uni1(x)
    p = 1 - normcdf(0, L(y, 1) * x + L(y, 2), 1);
    if p == 0, p = eps; end
    s = -log(p) + 0.5 * x.^2;
  end

end
