%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% data_partitioning:
%
% Partitions a dataset according to all possible combinations of (binary)
% values for the variables in "scope".
%
% Input:
%
% - Y: the data. THIS IS SUPPOSED TO BE ENCODED AS 0\1 INSTEAD OF -1\1
% - scope: set of variables
%   
% Output:
% 
% - idx: a set of data point indices corresponding to each configuration of
%        "scope"
%
% Created by: Ricardo Silva, London, 29/02/2012
% University College London
% Current version: 29/02/2012

function idx = data_partitioning(Y, scope)

N = size(Y, 1);
num_scope = length(scope);
config = binary_comb(num_scope);
num_config = length(config);
idx = cell(num_config, 1);

for i = 1:num_config
  idx{i} = find(sum(Y(:, scope) == repmat(config(i, :), N, 1), 2) == num_scope);
end